@@ -33,19 +33,15 @@ module Stringex
         end
 
         def klass_previous_instances(&block)
-          klass.all(:conditions => {settings.url_attribute => [nil]}).each(&block)
+          klass.all(conditions: {settings.url_attribute => [nil]}).each(&block)
         end
 
         def primary_key
           instance.class.key.first.instance_variable_get '@name'
         end
 
-        def read_attribute(instance, attribute)
-          instance.attributes[attribute]
-        end
-
         def url_owners
-          @url_owners ||= url_owners_class.all(:conditions => url_owner_conditions)
+          @url_owners ||= url_owners_class.all(conditions: url_owner_conditions)
         end
 
         def read_attribute(instance, name)
@@ -62,4 +58,4 @@ module Stringex
       end
     end
   end
-end
\ No newline at end of file
+end
